import pathlib


PROFILE_FILENAME = ".neosctl"
PROFILE_FILEPATH = pathlib.Path().home() / PROFILE_FILENAME


DEFAULT_PROFILE = "default"
